@@ -9,7 +9,7 @@ def get_client() -> elasticsearch.Elasticsearch:
     ds = get_data_source()
     base_auth = None
     if ds.get('username') is not None and ds.get('password') is not None:
-        base_auth = f'{ds.get("username")}:{ds.get("password")}'
+        base_auth = (ds.get('username'), ds.get('password'))
     return elasticsearch.Elasticsearch(
         hosts=[{'host': ds.get('host'), 'port': ds.get('port')}],
         basic_auth=base_auth,
